==> hinemos_src-3.0.4.tar.gz: Hinemos_src-3.0.4/PerformanceEJB/src/com/clustercontrol/performance/operator/TimeMeanPerTotal.java <==
/*
                                                                                                                                                                 
Copyright (C) 2008 NTT DATA Corporation
                                                                                                                                                                 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
                                                                                                                                                                 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
                                                                                                                                                                 
*/

package com.clustercontrol.performance.operator;

/**
 * 時間平均の合計を求める計算
 */
public class TimeMeanPerTotal extends SnmpOperator {
	@Override
	public double calc() throws CollectedDataNotFoundException, InvalidValueException{
		double perfData;	
		
		double uptimeDiff = getDifferenceValue("var0");
		
		// 分母が0の場合（更新されていない場合）
		if(uptimeDiff == 0){
			// エラー処理　おそらく値がとれていない
			return Double.NaN;
		}
		
		// 合計からvar0の分を差し引く
		//FIXME 値をdouble値で取得するため、丸め誤差が発生します。
		double totalDiff = getDifferenceValueTotal() - uptimeDiff;
		
		perfData = (double)totalDiff/(double)uptimeDiff * 100.0D;  // アップタイムは10ミリ秒単位のため
		
		return perfData;			
	}

}

==> hinemos_src-3.1.2.tar.gz: Hinemos_src-3.1.2/PerformanceEJB/src/com/clustercontrol/performance/operator/TimeMeanPerTotal.java <==
/*
                                                                                                                                                                 
Copyright (C) 2008 NTT DATA Corporation
                                                                                                                                                                 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
                                                                                                                                                                 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
                                                                                                                                                                 
*/

package com.clustercontrol.performance.operator;

/**
 * 時間平均の合計を求める計算
 */
public class TimeMeanPerTotal extends Operator {
	@Override
	public double calc() throws CollectedDataNotFoundException, InvalidValueException{
		double perfData;	
		
		double uptimeDiff = getDifferenceValue("var0");
		
		// 分母が0の場合（更新されていない場合）
		if(uptimeDiff == 0){
			// エラー処理　おそらく値がとれていない
			return Double.NaN;
		}
		
		// 合計からvar0の分を差し引く
		//FIXME 値をdouble値で取得するため、丸め誤差が発生します。
		double totalDiff = getDifferenceValueTotal() - uptimeDiff;
		
		perfData = (double)totalDiff/(double)uptimeDiff * 100.0D;  // アップタイムは10ミリ秒単位のため
		
		return perfData;			
	}

}
